@@ -1,23 +1,9 @@
 /*
-    Copyright 2008,2010 Will Stephenson <wstephenson@kde.org>
-    Copyright 2013 Daniel Nicoletti <dantti12@gmail.com>
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2008, 2010 Will Stephenson <wstephenson@kde.org>
+    SPDX-FileCopyrightText: 2013 Daniel Nicoletti <dantti12@gmail.com>
+    SPDX-FileCopyrightText: 2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "device_p.h"
@@ -248,18 +234,22 @@ void NetworkManager::DevicePrivate::propertyChanged(const QString &property, con
         Q_EMIT q->autoconnectChanged();
     } else if (property == QLatin1String("AvailableConnections")) {
         QStringList newAvailableConnections;
-        QList<QDBusObjectPath> availableConnectionsTmp = qdbus_cast< QList<QDBusObjectPath> >(value);
-        Q_FOREACH (const QDBusObjectPath & availableConnection, availableConnectionsTmp) {
+        const QList<QDBusObjectPath> availableConnectionsTmp = qdbus_cast< QList<QDBusObjectPath> >(value);
+        for (const QDBusObjectPath &availableConnection : availableConnectionsTmp) {
             newAvailableConnections << availableConnection.path();
             if (!availableConnections.contains(availableConnection.path())) {
                 availableConnections << availableConnection.path();
                 Q_EMIT q->availableConnectionAppeared(availableConnection.path());
             }
         }
-        Q_FOREACH (const QString & availableConnection, availableConnections) {
+        auto it = availableConnections.begin();
+        while (it != availableConnections.end()) {
+            const QString availableConnection = *it;
             if (!newAvailableConnections.contains(availableConnection)) {
-                availableConnections.removeOne(availableConnection);
+                it = availableConnections.erase(it);
                 Q_EMIT q->availableConnectionDisappeared(availableConnection);
+            } else {
+                ++it;
             }
         }
         Q_EMIT q->availableConnectionChanged();
@@ -416,7 +406,7 @@ NetworkManager::Connection::List NetworkManager::Device::availableConnections()
     Q_D(const Device);
 
     NetworkManager::Connection::List list;
-    Q_FOREACH (const QString & availableConnection, d->availableConnections) {
+    for (const QString &availableConnection : qAsConst(d->availableConnections)) {
         NetworkManager::Connection::Ptr connection = NetworkManager::findConnection(availableConnection);
         if (connection) {
             list << connection;
