@@ -1,21 +1,7 @@
 /*
-    Copyright 2014 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2014 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "connection.h"
@@ -196,15 +182,17 @@ void FakeNetwork::registerService()
     QDBusConnection::sessionBus().registerObject(QLatin1String("/org/kde/fakenetwork"), this, QDBusConnection::ExportScriptableContents);
     QDBusConnection::sessionBus().registerObject(QLatin1String("/org/kde/fakenetwork/Settings"), m_settings, QDBusConnection::ExportScriptableContents);
 
-    Q_FOREACH (const QDBusObjectPath & devicePath, m_devices.keys()) {
-        QDBusConnection::sessionBus().registerObject(devicePath.path(), m_devices.value(devicePath), QDBusConnection::ExportScriptableContents);
+    for (auto it = m_devices.cbegin(); it != m_devices.cend(); ++it) {
+        const QDBusObjectPath &devicePath = it.key();
+        QDBusConnection::sessionBus().registerObject(devicePath.path(), it.value(), QDBusConnection::ExportScriptableContents);
         Q_EMIT DeviceAdded(devicePath);
     }
 }
 
 void FakeNetwork::unregisterService()
 {
-    Q_FOREACH (const QDBusObjectPath & devicePath, m_devices.keys()) {
+    for (auto it = m_devices.cbegin(); it != m_devices.cend(); ++it) {
+        const QDBusObjectPath &devicePath = it.key();
         QDBusConnection::sessionBus().unregisterObject(devicePath.path());
         Q_EMIT DeviceRemoved(devicePath);
     }
@@ -418,7 +406,7 @@ void FakeNetwork::onConnectionAdded(const QDBusObjectPath &connection)
         NetworkManager::ConnectionSettings::ConnectionType type = NetworkManager::ConnectionSettings::typeFromString(settings.value(QLatin1String("connection")).value(QLatin1String("type")).toString());
         if (!m_devices.isEmpty()) {
             Device *selectedDevice = nullptr;
-            Q_FOREACH (Device * device, m_devices.values()) {
+            for (Device *device : qAsConst(m_devices)) {
                 if (type == NetworkManager::ConnectionSettings::Wired && device->deviceType() == NetworkManager::Device::Ethernet) {
                     selectedDevice = device;
                     device->addAvailableConnection(connection);
@@ -444,7 +432,7 @@ void FakeNetwork::onConnectionAdded(const QDBusObjectPath &connection)
 
 void FakeNetwork::onConnectionRemoved(const QDBusObjectPath &connection)
 {
-    Q_FOREACH (Device * device, m_devices.values()) {
+    for (Device *device : qAsConst(m_devices)) {
         if (device && device->availableConnections().contains(connection)) {
             device->removeAvailableConnection(connection);
 
