@@ -1,37 +1,16 @@
 /*
-    Copyright 2012-2013  Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2012-2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "gsmsetting.h"
 #include "gsmsetting_p.h"
 
-#if !NM_CHECK_VERSION(1, 0, 0)
-#include <nm-setting-gsm.h>
-#endif
-
-//define the deprecated&dropped values
-#if NM_CHECK_VERSION(1, 0, 0)
 #define NM_SETTING_GSM_NETWORK_TYPE "network-type"
 #define NM_SETTING_GSM_ALLOWED_BANDS "allowed-bands"
-#endif
 
-#include <QtCore/QDebug>
+#include <QDebug>
 
 NetworkManager::GsmSettingPrivate::GsmSettingPrivate()
     : name(NM_SETTING_GSM_SETTING_NAME)
@@ -62,6 +41,9 @@ NetworkManager::GsmSetting::GsmSetting(const Ptr &other)
     setPinFlags(other->pinFlags());
     setAllowedBand(other->allowedBand());
     setHomeOnly(other->homeOnly());
+    setDeviceId(other->deviceId());
+    setSimId(other->simId());
+    setSimOperatorId(other->simOperatorId());
 }
 
 NetworkManager::GsmSetting::~GsmSetting()
@@ -230,6 +212,48 @@ bool NetworkManager::GsmSetting::homeOnly() const
     return d->homeOnly;
 }
 
+void NetworkManager::GsmSetting::setDeviceId(const QString &id)
+{
+    Q_D(GsmSetting);
+
+    d->deviceId = id;
+}
+
+QString NetworkManager::GsmSetting::deviceId() const
+{
+    Q_D(const GsmSetting);
+
+    return d->deviceId;
+}
+
+void NetworkManager::GsmSetting::setSimId(const QString &id)
+{
+    Q_D(GsmSetting);
+
+    d->simId = id;
+}
+
+QString NetworkManager::GsmSetting::simId() const
+{
+    Q_D(const GsmSetting);
+
+    return d->simId;
+}
+
+void NetworkManager::GsmSetting::setSimOperatorId(const QString &id)
+{
+    Q_D(GsmSetting);
+
+    d->simOperatorId = id;
+}
+
+QString NetworkManager::GsmSetting::simOperatorId() const
+{
+    Q_D(const GsmSetting);
+
+    return d->simOperatorId;
+}
+
 void NetworkManager::GsmSetting::secretsFromMap(const QVariantMap &secrets)
 {
     if (secrets.contains(QLatin1String(NM_SETTING_GSM_PASSWORD))) {
@@ -314,9 +338,22 @@ void NetworkManager::GsmSetting::fromMap(const QVariantMap &setting)
     if (setting.contains(QLatin1String(NM_SETTING_GSM_ALLOWED_BANDS))) {
         setAllowedBand(setting.value(QLatin1String(NM_SETTING_GSM_ALLOWED_BANDS)).toUInt());
     }
+
     if (setting.contains(QLatin1String(NM_SETTING_GSM_HOME_ONLY))) {
         setHomeOnly(setting.value(QLatin1String(NM_SETTING_GSM_HOME_ONLY)).toBool());
     }
+
+    if (setting.contains(QLatin1String(NM_SETTING_GSM_DEVICE_ID))) {
+        setDeviceId(setting.value(QLatin1String(NM_SETTING_GSM_DEVICE_ID)).toString());
+    }
+
+    if (setting.contains(QLatin1String(NM_SETTING_GSM_SIM_ID))) {
+        setSimId(setting.value(QLatin1String(NM_SETTING_GSM_SIM_ID)).toString());
+    }
+
+    if (setting.contains(QLatin1String(NM_SETTING_GSM_SIM_OPERATOR_ID))) {
+        setSimOperatorId(setting.value(QLatin1String(NM_SETTING_GSM_SIM_OPERATOR_ID)).toString());
+    }
 }
 
 QVariantMap NetworkManager::GsmSetting::toMap() const
@@ -363,6 +400,18 @@ QVariantMap NetworkManager::GsmSetting::toMap() const
         setting.insert(QLatin1String(NM_SETTING_GSM_HOME_ONLY), homeOnly());
     }
 
+    if (!deviceId().isEmpty()) {
+        setting.insert(QLatin1String(NM_SETTING_GSM_DEVICE_ID), deviceId());
+    }
+
+    if (!simId().isEmpty()) {
+        setting.insert(QLatin1String(NM_SETTING_GSM_SIM_ID), simId());
+    }
+
+    if (!simOperatorId().isEmpty()) {
+        setting.insert(QLatin1String(NM_SETTING_GSM_SIM_OPERATOR_ID), simOperatorId());
+    }
+
     return setting;
 }
 
@@ -382,6 +431,9 @@ QDebug NetworkManager::operator <<(QDebug dbg, const NetworkManager::GsmSetting
     dbg.nospace() << NM_SETTING_GSM_PIN << ": " << setting.pin() << '\n';
     dbg.nospace() << NM_SETTING_GSM_PIN_FLAGS << ": " << setting.pinFlags() << '\n';
     dbg.nospace() << NM_SETTING_GSM_HOME_ONLY << ": " << setting.homeOnly() << '\n';
+    dbg.nospace() << NM_SETTING_GSM_DEVICE_ID << ": " << setting.deviceId() << '\n';
+    dbg.nospace() << NM_SETTING_GSM_SIM_ID << ": " << setting.simId() << '\n';
+    dbg.nospace() << NM_SETTING_GSM_SIM_OPERATOR_ID << ": " << setting.simOperatorId() << '\n';
 
     return dbg.maybeSpace();
 }
